! =================================================================================================================================
! MODULE       : stomate_lcchange
!
! CONTACT      : orchidee-help _at_ listes.ipsl.fr
!
! LICENCE      : IPSL (2006)
! This software is governed by the CeCILL licence see ORCHIDEE/ORCHIDEE_CeCILL.LIC
!
!>\BRIEF       Impact of land cover change on carbon stocks
!!
!!\n DESCRIPTION: None
!!
!! RECENT CHANGE(S): Separate subroutines for land cover change and wood use 
!!
!! REFERENCE(S)	: None
!!
!! SVN          :
!! $HeadURL$
!! $Date$
!! $Revision$
!! \n
!_ ================================================================================================================================


MODULE stomate_lcchange

  ! modules used:
  
  USE ioipsl_para
  USE stomate_data
  USE pft_parameters
  USE constantes
  
  IMPLICIT NONE
  
  PRIVATE
  PUBLIC lcchange_main, product_init, wood_use_main
  
CONTAINS


!! ================================================================================================================================
!! SUBROUTINE   : lcchange_main
!!
!>\BRIEF        Impact of land cover change on carbon stocks
!!
!! DESCRIPTION  : This subroutine is always activate if VEGET_UPDATE>0Y in the configuration file, which means that the 
!! vegetation map is updated regulary. lcchange_main is called from stomateLpj the first time step after the vegetation 
!! map has been changed. 
!! The impact of land cover change on carbon stocks is computed in this subroutine. The land cover change is written
!! by the difference of current and previous "maximal" coverage fraction of a PFT. 
!! On the basis of this difference, the amount of 'new establishment'/'biomass export',
!! and increase/decrease of each component, are estimated.\n
!!
!! Main structure of lcchange_main is:
!! 1. Initialization
!! 2. Calculation of changes in carbon stocks and biomass by land cover change
!! 4. Writing output
!!
!! RECENT CHANGE(S) : None
!!
!! MAIN OUTPUT VARIABLE(S) : ::biomass, ::ind, ::litter, ::som,
!!   ::co2_to_bm, ::tree_bm_to_litter
!!
!! REFERENCES   : None
!!
!! FLOWCHART    : 
!! \latexonly 
!!     \includegraphics[scale=0.5]{lcchange.png}
!! \endlatexonly
!! \n
!_ ================================================================================================================================
  
  SUBROUTINE lcchange_main ( npts, dt_days, veget_cov_max_old, veget_cov_max_new, &
       biomass, ind, age, PFTpresent, senescence, when_growthinit, everywhere, &        
       co2_to_bm, bm_to_litter, tree_bm_to_litter, turnover_daily, bm_sapl_2D, cn_ind, &
       flux10,flux100, prod10,prod100, convflux, nflux_prod_total, leaf_frac, &
       npp_longterm, lm_lastyearmax, litter, som, deepSOM_a, deepSOM_s, deepSOM_p, &
       soil_n_min, KF, k_latosa_adapt, rue_longterm, lignin_struc, lignin_wood, &
       convfluxpft, fDeforestToProduct, fLulccResidue, sugar_load)


    IMPLICIT NONE
    
  !! 0. Variable and parameter declaration 
    
    !! 0.1 Input variables
    
    INTEGER, INTENT(in)                                       :: npts             !! Domain size - number of pixels (unitless)
    REAL(r_std), INTENT(in)                                   :: dt_days          !! Time step of vegetation dynamics for stomate
                                                                                  !! (days)
    REAL(r_std), DIMENSION(npts,nvm,nparts,nelements),INTENT(in) :: bm_sapl_2D    !! biomass of sapling 
                                                                                  !! @tex ($gC individual^{-1}$) @endtex
    REAL(r_std), DIMENSION(npts,nvm), INTENT(in)              :: veget_cov_max_old!! Current "maximal" coverage fraction of a PFT (LAI
                                                                                  !! -> infinity) on ground
    REAL(r_std), DIMENSION(npts,nvm), INTENT(in)              :: veget_cov_max_new!! New "maximal" coverage fraction of a PFT (LAI ->
                                                                                  !! infinity) on ground (unitless) 
    !! 0.2 Output variables

    REAL(r_std), DIMENSION(npts), INTENT(out)                 :: convflux         !! release during first year following land cover
                                                                                  !! change
    REAL(r_std), DIMENSION(npts), INTENT(out)                 :: nflux_prod_total !! release of N associated to land cover change  @tex ($gN m^{-2}$) @endtex 
    REAL(r_std), DIMENSION(npts,nvm,nparts,nelements), INTENT(inout):: turnover_daily   !! Turnover rates 
    REAL(r_std), DIMENSION(npts,nvm), INTENT(out)             :: convfluxpft      !! release during first year following land cover                                       
                                                                                  !! change   
    REAL(r_std), DIMENSION(npts,nvm), INTENT(out)             :: fDeforestToProduct !!  Deforested biomass into product pool due to anthorpogenic 
                                                                                    !! land use change
    REAL(r_std), DIMENSION(npts,nvm), INTENT(out)             :: fLulccResidue      !!  carbon mass flux into soil and litter due to anthropogenic land use or land cover change

    !! 0.3 Modified variables   
    
    REAL(r_std), DIMENSION(npts,nvm,nparts,nelements), INTENT(inout):: biomass    !! biomass @tex ($gC m^{-2}$) @endtex
    REAL(r_std), DIMENSION(npts,nvm), INTENT(inout)           :: ind              !! Number of individuals @tex ($m^{-2}$) @endtex
    REAL(r_std), DIMENSION(npts,nvm), INTENT(inout)           :: age              !! mean age (years)
    LOGICAL, DIMENSION(npts,nvm), INTENT(inout)               :: senescence       !! plant senescent (only for deciduous trees) Set
                                                                                  !! to .FALSE. if PFT is introduced or killed
    LOGICAL, DIMENSION(npts,nvm), INTENT(inout)               :: PFTpresent       !! Is pft there (unitless)
    REAL(r_std), DIMENSION(npts,nvm), INTENT(inout)           :: everywhere       !! is the PFT everywhere in the grid box or very 
                                                                                  !! localized (unitless)
    REAL(r_std), DIMENSION(npts,nvm), INTENT(inout)           :: when_growthinit  !! how many days ago was the beginning of the 
                                                                                  !! growing season (days)
    REAL(r_std), DIMENSION(npts,nvm), INTENT(inout)           :: co2_to_bm        !! biomass uptaken 
                                                                                  !! @tex ($gC m^{-2} day^{-1}$) @endtex
    REAL(r_std), DIMENSION(npts,nvm,nparts,nelements), INTENT(inout) :: bm_to_litter !! conversion of biomass to litter 
                                                                                  !! @tex ($gC m^{-2} day^{-1}$) @endtex
    REAL(r_std), DIMENSION(npts,nvm,nparts,nelements), INTENT(inout) :: tree_bm_to_litter !! conversion of biomass to litter 
                                                                                  !! @tex ($gC m^{-2} day^{-1}$) @endtex
    REAL(r_std), DIMENSION(npts,nvm), INTENT(inout)           :: cn_ind           !! crown area of individuals 
                                                                                  !! @tex ($m^{2}$) @endtex
    REAL(r_std), DIMENSION(npts,0:10), INTENT(inout)          :: prod10           !! products remaining in the 10 year-turnover
                                                                                  !! pool after the annual release for each 
                                                                                  !! compartment (10 + 1 : input from year of land
                                                                                  !! cover change)
    REAL(r_std), DIMENSION(npts,0:100), INTENT(inout)         :: prod100          !! products remaining in the 100 year-turnover
                                                                                  !! pool after the annual release for each 
                                                                                  !! compartment (100 + 1 : input from year of land
                                                                                  !! cover change)
    REAL(r_std), DIMENSION(npts,10), INTENT(inout)            :: flux10           !! annual release from the 10/100 year-turnover 
                                                                                  !! pool compartments
    REAL(r_std), DIMENSION(npts,100), INTENT(inout)           :: flux100          !! annual release from the 10/100 year-turnover
                                                                                  !! pool compartments
    REAL(r_std), DIMENSION(npts,nvm,nleafages), INTENT(inout) :: leaf_frac        !! fraction of leaves in leaf age class 
                                                                                  !! (unitless)
    REAL(r_std), DIMENSION(npts,nvm), INTENT(inout)           :: lm_lastyearmax   !! last year's maximum leaf mass for each PFT 
                                                                                  !! @tex ($gC m^{-2}$) @endtex
    REAL(r_std), DIMENSION(npts,nvm), INTENT(inout)           :: npp_longterm     !! "long term" net primary productivity 
                                                                                  !! @tex ($gC m^{-2} year^{-1}$) @endtex
    REAL(r_std),DIMENSION(npts,nlitt,nvm,nlevs,nelements), INTENT(inout):: litter !! metabolic and structural litter, above and 
                                                                                  !! below ground @tex ($gC m^{-2}$) @endtex
    REAL(r_std),DIMENSION(npts,ncarb,nvm,nelements), INTENT(inout)      :: som    !! SOM pool: active, slow, or passive  
  !! @tex ($g(C or N) m^{-2}$) @endtex 
    REAL(r_std), DIMENSION(npts,ngrnd,nvm,nelements), INTENT(inout) :: deepSOM_a  !! Soil carbon discretized with depth active (g/m**3)
    REAL(r_std), DIMENSION(npts,ngrnd,nvm,nelements), INTENT(inout) :: deepSOM_s  !! Soil carbon discretized with depth slow (g/m**3)
    REAL(r_std), DIMENSION(npts,ngrnd,nvm,nelements), INTENT(inout) :: deepSOM_p  !! Soil carbon discretized with depth passive (g/m**3)

    REAL(r_std),DIMENSION(npts,nvm,nnspec), INTENT(inout)     :: soil_n_min       !!  soil mineral nitrogen pool 
    REAL(r_std), DIMENSION(npts,nvm,nlevs), INTENT(inout)     :: lignin_struc     !! ratio Lignine/Carbon in structural litter,
                                                                                  !! above and below ground
    REAL(r_std), DIMENSION(npts,nvm,nlevs), INTENT(inout)     :: lignin_wood      !! ratio Lignine/Carbon in woody litter,
                                                                                  !! above and below ground
    REAL(r_std), DIMENSION(:,:), INTENT(inout)                :: KF               !! Scaling factor to convert sapwood mass
    REAL(r_std), DIMENSION(:,:), INTENT(inout)                :: k_latosa_adapt   !! Leaf to sapwood area adapted for long 
    REAL(r_std), DIMENSION(:,:), INTENT(inout)                :: rue_longterm     !! Longterm radiation use efficiency 
    REAL(r_std), DIMENSION(npts,nvm), INTENT(inout)              :: sugar_load 
 
    !! 0.4 Local variables

    INTEGER(i_std)                                            :: i, j, k, l, m    !! indices (unitless)
    REAL(r_std),DIMENSION(npts,nelements)                     :: bm_new           !! biomass increase @tex ($gC m^{-2}$) @endtex
    REAL(r_std),DIMENSION(npts,nparts,nelements)              :: biomass_loss     !! biomass loss @tex ($gC m^{-2}$) @endtex
    REAL(r_std),DIMENSION(npts,nparts,nelements)              :: tree_biomass_loss     !! tree biomass loss @tex ($gC m^{-2}$) @endtex
    
    REAL(r_std)                                               :: above            !! aboveground biomass @tex ($gC m^{-2}$) @endtex
    REAL(r_std),DIMENSION(npts,nlitt,nlevs,nelements)         :: dilu_lit         !! Litter dilution @tex ($gC m^{-2}$) @endtex
    REAL(r_std),DIMENSION(npts,ncarb,nelements)               :: dilu_som         !! SOM dilution @tex ($g(C or N) m^{-2}$) @endtex 
    REAL(r_std),DIMENSION(npts,ngrnd,ncarb,nelements)         :: dilu_som_vertres !! Vertically-resolved SOM dilution (gC/m**3)
    REAL(r_std),DIMENSION(npts,nnspec)                        :: dilu_sin         !! Soil Inorganic Nitrogen dilution @tex ($gN m^{-2}$) @endtex     
  !! Soil Inorganic Nitrogen dilution @tex ($gN m^{-2}$) @endtex
    REAL(r_std),DIMENSION(npts,nlevs)                         :: dilu_lf_struc    !! fraction of structural litter that is lignin
                                                                                  !! (0-1,unitless)
    REAL(r_std),DIMENSION(npts,nlevs)                         :: dilu_lf_wood     !! fraction of woody litter that is lignin
                                                                                  !! (0-1,unitless)
    REAL(r_std),DIMENSION(nvm)                                :: delta_veg        !! changes in "maximal" coverage fraction of PFT 
    REAL(r_std)                                               :: delta_veg_sum    !! sum of delta_veg
    REAL(r_std),DIMENSION(npts,nvm)                           :: delta_ind        !! change in number of individuals  

!_ ================================================================================================================================

    IF (printlev>=3) WRITE(numout,*) 'Entering lcchange_main'
    
  !! 1. initialization
    prod10(:,0)         = zero
    prod100(:,0)        = zero    
    above               = zero
    convflux(:)         = zero
    convfluxpft(:,:)    = zero
    delta_ind(:,:)      = zero
    delta_veg(:)        = zero
    nflux_prod_total(:) = zero 
    fDeforestToProduct(:,:)  = zero
    fLulccResidue(:,:)       = zero
    dilu_som_vertres(:,:,:,:) = zero
    
  !! 3. calculation of changes in carbon stocks and biomass by land cover change\n
    
    DO i = 1, npts ! Loop over # pixels - domain size
       
       !! 3.1 initialization of carbon stocks\n
       delta_veg(:) = veget_cov_max_new(i,:)-veget_cov_max_old(i,:)
       delta_veg_sum = SUM(delta_veg,MASK=delta_veg.LT.0.)
      
       dilu_lit(i,:,:,:) = zero
       dilu_som(i,:,:) = zero
       biomass_loss(i,:,:) = zero
       tree_biomass_loss(i,:,:) = zero
       dilu_sin(i,:) = zero 
       dilu_lf_struc(i,:) = zero
       dilu_lf_wood(i,:) = zero
 
       !! 3.2 if vegetation coverage decreases, compute dilution of litter, soil carbon, and biomass.\n
       DO j=2, nvm
          IF ( delta_veg(j) < -min_stomate ) THEN 
             dilu_lit(i,:,:,:) = dilu_lit(i,:,:,:) + delta_veg(j)*litter(i,:,j,:,:) / delta_veg_sum
             IF ( ok_soil_carbon_discretization ) THEN
                DO k=1,nelements
                    dilu_som_vertres(i,:,iactive,k)=dilu_som_vertres(i,:,iactive,k) + &
                         delta_veg(j) * deepSOM_a(i,:,j,k) / delta_veg_sum
                    dilu_som_vertres(i,:,islow,k)=dilu_som_vertres(i,:,islow,k) + &
                         delta_veg(j) * deepSOM_s(i,:,j,k) / delta_veg_sum
                    dilu_som_vertres(i,:,ipassive,k)=dilu_som_vertres(i,:,ipassive,k) + &
                         delta_veg(j) * deepSOM_p(i,:,j,k) / delta_veg_sum
                 ENDDO
             ELSE

             dilu_som(i,:,:) =  dilu_som(i,:,:) + delta_veg(j) * som(i,:,j,:) / delta_veg_sum 

             ENDIF

             dilu_sin(i,:)=  dilu_sin(i,:) + delta_veg(j) * soil_n_min(i,j,:) / delta_veg_sum 
             dilu_lf_struc(i,:) = dilu_lf_struc(i,:) + &
                  delta_veg(j) * lignin_struc(i,j,:)* litter(i,istructural,j,:,icarbon) / delta_veg_sum
             dilu_lf_wood(i,:) = dilu_lf_wood(i,:) + &
                  delta_veg(j) * lignin_wood(i,j,:)*litter(i,iwoody,j,:,icarbon) / delta_veg_sum
             biomass_loss(i,:,:) = biomass_loss(i,:,:) + biomass(i,j,:,:)*delta_veg(j) / delta_veg_sum
             IF(is_tree(j)) THEN
                 tree_biomass_loss(i,:,:) = tree_biomass_loss(i,:,:) + biomass(i,j,:,:)*delta_veg(j) / delta_veg_sum
              ENDIF
          ENDIF
       ENDDO
       
       !! 3.3 
       DO j=2, nvm ! Loop over # PFTs

          !! 3.3.1 The case that vegetation coverage of PFTj increases
          IF ( delta_veg(j) > min_stomate) THEN

             !! 3.3.1.1 Initial setting of new establishment
             IF (veget_cov_max_old(i,j) .LT. min_stomate) THEN 
                IF (is_tree(j)) THEN

                   ! cn_sapl(j)=0.5; stomate_data.f90
                   cn_ind(i,j) = cn_sapl(j) 
                ELSE
                   cn_ind(i,j) = un
                ENDIF
                ind(i,j)= delta_veg(j) / cn_ind(i,j)
                PFTpresent(i,j) = .TRUE.
                everywhere(i,j) = 1.
                senescence(i,j) = .FALSE.
                age(i,j) = zero

                ! large_value = 1.E33_r_std
                when_growthinit(i,j) = large_value 
                leaf_frac(i,j,1) = 1.0
                npp_longterm(i,j) = npp_longterm_init
                lm_lastyearmax(i,j) = bm_sapl_2D(i,j,ileaf,icarbon) * ind(i,j)
             ENDIF
             IF ( cn_ind(i,j) > min_stomate ) THEN
                delta_ind(i,j) = delta_veg(j) / cn_ind(i,j) 
             ENDIF
             
             !! 3.3.1.2 Update of biomass in each each carbon stock component 
             !!         Update of biomass in each each carbon stock component (leaf, sapabove, sapbelow,
             !>         heartabove, heartbelow, root, fruit, and carbres)\n
             DO k = 1, nparts ! loop over # carbon stock components, nparts = 8; stomate_constant.f90 
                DO l = 1,nelements ! loop over # elements

                   bm_new(i,l) = delta_ind(i,j) * bm_sapl_2D(i,j,k,l) 
                   IF (veget_cov_max_old(i,j) .GT. min_stomate) THEN

                      ! in the case that bm_new is overestimated compared with biomass?
                      IF ((bm_new(i,l)/delta_veg(j)) > biomass(i,j,k,l)) THEN
                         bm_new(i,l) = biomass(i,j,k,l)*delta_veg(j)
                      ENDIF
                   ENDIF
                   biomass(i,j,k,l) = ( biomass(i,j,k,l) * veget_cov_max_old(i,j) + bm_new(i,l) ) / veget_cov_max_new(i,j)
                   IF (l==icarbon) THEN
                      co2_to_bm(i,j) = co2_to_bm(i,j) + (bm_new(i,icarbon)* dt_days) / (one_year * veget_cov_max_new(i,j))
                   ENDIF
                END DO ! loop over # elements
             ENDDO ! loop over # carbon stock components

             !! 3.3.1.3 Calculation of dilution in litter, soil carbon, and  input of litter
             !!        In this 'IF statement', dilu_* is zero. Formulas for litter and soil carbon
             !!         could be shortend?? Are the following formulas correct?
             
             
             ! Lignin fraction of structural litter
             lignin_struc(i,j,:)=(lignin_struc(i,j,:) * veget_cov_max_old(i,j)* litter(i,istructural,j,:,icarbon) + & 
                  dilu_lf_struc(i,:) * delta_veg(j)) / veget_cov_max_new(i,j) 

             ! Lignin fraction of woody litter
             lignin_wood(i,j,:)=(lignin_wood(i,j,:) * veget_cov_max_old(i,j)* litter(i,iwoody,j,:,icarbon) + & 
                  dilu_lf_wood(i,:) * delta_veg(j)) / veget_cov_max_new(i,j)

             ! Litter
             litter(i,:,j,:,:)=(litter(i,:,j,:,:) * veget_cov_max_old(i,j) + &
                  dilu_lit(i,:,:,:) * delta_veg(j)) / veget_cov_max_new(i,j)
            
             WHERE ( litter(i,istructural,j,:,icarbon) > min_stomate )
                lignin_struc(i,j,:) = lignin_struc(i,j,:)/litter(i,istructural,j,:,icarbon)
             ELSEWHERE
                lignin_struc(i,j,:) = LC_leaf(j)
             ENDWHERE

             WHERE ( litter(i,iwoody,j,:,icarbon) > min_stomate )
                lignin_wood(i,j,:) = lignin_wood(i,j,:)/litter(i,iwoody,j,:,icarbon)
             ELSEWHERE
                lignin_wood(i,j,:) = LC_heartabove(j)
             ENDWHERE

             ! Soil Organic Matter
             IF ( ok_soil_carbon_discretization ) THEN
                DO k=1,nelements
                deepSOM_a(i,:,j,k)=(deepSOM_a(i,:,j,k) * veget_cov_max_old(i,j) + &
                     dilu_som_vertres(i,:,iactive,k) * delta_veg(j)) / veget_cov_max_new(i,j)
                deepSOM_s(i,:,j,k)=(deepSOM_s(i,:,j,k) * veget_cov_max_old(i,j) + &
                     dilu_som_vertres(i,:,islow,k) * delta_veg(j)) / veget_cov_max_new(i,j)
                deepSOM_p(i,:,j,k)=(deepSOM_p(i,:,j,k) * veget_cov_max_old(i,j) + &
                     dilu_som_vertres(i,:,ipassive,k) * delta_veg(j)) / veget_cov_max_new(i,j)
                 ENDDO
             ELSE 
             som(i,:,j,:)=(som(i,:,j,:) * veget_cov_max_old(i,j) + dilu_som(i,:,:) * delta_veg(j)) / veget_cov_max_new(i,j) 
 	     ENDIF

             ! Soil inorganic nitrogen  
             soil_n_min(i,j,:)=(soil_n_min(i,j,:) * veget_cov_max_old(i,j) + &  
                  dilu_sin(i,:) * delta_veg(j)) / veget_cov_max_new(i,j) 

             DO l = 1,nelements

                ! Litter input
                bm_to_litter(i,j,isapbelow,l) = (bm_to_litter(i,j,isapbelow,l) * veget_cov_max_old(i,j) + &
                     biomass_loss(i,isapbelow,l)*delta_veg(j)) / veget_cov_max_new(i,j)
                bm_to_litter(i,j,iheartbelow,l) = (bm_to_litter(i,j,iheartbelow,l) * veget_cov_max_old(i,j) + &
                     biomass_loss(i,iheartbelow,l) *delta_veg(j)) / veget_cov_max_new(i,j)
                bm_to_litter(i,j,iroot,l) = (bm_to_litter(i,j,iroot,l) * veget_cov_max_old(i,j) + &
                     biomass_loss(i,iroot,l)*delta_veg(j)) / veget_cov_max_new(i,j)
                bm_to_litter(i,j,ifruit,l) = (bm_to_litter(i,j,ifruit,l) * veget_cov_max_old(i,j) + &
                     biomass_loss(i,ifruit,l)*delta_veg(j)) / veget_cov_max_new(i,j)
                bm_to_litter(i,j,icarbres,l) = (bm_to_litter(i,j,icarbres,l) * veget_cov_max_old(i,j) + &
                     biomass_loss(i,icarbres,l)   *delta_veg(j)) / veget_cov_max_new(i,j)
                bm_to_litter(i,j,ilabile,l) = (bm_to_litter(i,j,ilabile,l) * veget_cov_max_old(i,j) + &
                     biomass_loss(i,ilabile,l)   *delta_veg(j)) / veget_cov_max_new(i,j)
                bm_to_litter(i,j,ileaf,l) = (bm_to_litter(i,j,ileaf,l) * veget_cov_max_old(i,j) + &
                     biomass_loss(i,ileaf,l)*delta_veg(j)) / veget_cov_max_new(i,j)

                !*****************
                tree_bm_to_litter(i,j,isapbelow,l) = (tree_bm_to_litter(i,j,isapbelow,l) * veget_cov_max_old(i,j) + &
                     tree_biomass_loss(i,isapbelow,l) * delta_veg(j)) / veget_cov_max_new(i,j)
                tree_bm_to_litter(i,j,iheartbelow,l) = (tree_bm_to_litter(i,j,iheartbelow,l) * veget_cov_max_old(i,j) + &
                     tree_biomass_loss(i,iheartbelow,l) * delta_veg(j)) / veget_cov_max_new(i,j)
                tree_bm_to_litter(i,j,iroot,l) = (tree_bm_to_litter(i,j,iroot,l) * veget_cov_max_old(i,j) + &
                     tree_biomass_loss(i,iroot,l) * delta_veg(j)) / veget_cov_max_new(i,j)
                tree_bm_to_litter(i,j,ifruit,l) = (tree_bm_to_litter(i,j,ifruit,l) * veget_cov_max_old(i,j) + &
                     tree_biomass_loss(i,ifruit,l) * delta_veg(j)) / veget_cov_max_new(i,j)
                tree_bm_to_litter(i,j,icarbres,l) = (tree_bm_to_litter(i,j,icarbres,l) * veget_cov_max_old(i,j) + &
                     tree_biomass_loss(i,icarbres,l) * delta_veg(j)) / veget_cov_max_new(i,j)
                tree_bm_to_litter(i,j,ilabile,l) = (tree_bm_to_litter(i,j,ilabile,l) * veget_cov_max_old(i,j) + &
                     tree_biomass_loss(i,ilabile,l) * delta_veg(j)) / veget_cov_max_new(i,j)
                tree_bm_to_litter(i,j,ileaf,l) = (tree_bm_to_litter(i,j,ileaf,l) * veget_cov_max_old(i,j) + &
                     tree_biomass_loss(i,ileaf,l) * delta_veg(j)) / veget_cov_max_new(i,j)
                
             

             END DO

             age(i,j)=age(i,j)*veget_cov_max_old(i,j)/veget_cov_max_new(i,j)
             
          !! 3.3.2 The case that vegetation coverage of PFTj is no change or decreases
          ELSE 
 
             !! 3.3.2.1 Biomass export
             ! coeff_lcchange_*:  Coeff of biomass export for the year, decade, and century
             above = biomass(i,j,isapabove,icarbon) + biomass(i,j,iheartabove,icarbon)
             convflux(i)  = convflux(i)  - ( coeff_lcchange_1(j) * above * delta_veg(j) ) 
             convfluxpft(i,j)= convfluxpft(i,j) - (coeff_lcchange_1(j) * above * delta_veg(j) )
             prod10(i,0)  = prod10(i,0)  - ( coeff_lcchange_10(j) * above * delta_veg(j) )
             prod100(i,0) = prod100(i,0) - ( coeff_lcchange_100(j) * above * delta_veg(j) )


             ! Calulate diagnostic variables
             fDeforestToProduct(i,j) = - above * delta_veg(j)
             fLulccResidue(i,j) = - ( biomass(i,j,isapbelow,icarbon) &
                  + biomass(i,j,iheartbelow,icarbon) &
                  + biomass(i,j,iroot,icarbon) &
                  + biomass(i,j,ifruit,icarbon) &
                  + biomass(i,j,icarbres,icarbon) &
                  + biomass(i,j,ileaf,icarbon) ) * delta_veg(j)

             ! Exported nitrogen biomasse asociated with land use change
             above = biomass(i,j,isapabove,initrogen) + biomass(i,j,iheartabove,initrogen) 
             nflux_prod_total(i) = nflux_prod_total(i) - above* delta_veg(j)


             !! If the vegetation is to small, it has been set to 0.
             IF ( veget_cov_max_new(i,j) .LT. min_stomate ) THEN 
                
                ind(i,j) = zero
                biomass(i,j,:,:) = zero
                PFTpresent(i,j) = .FALSE.
                senescence(i,j) = .FALSE.
                age(i,j) = zero
                when_growthinit(i,j) = undef
                everywhere(i,j) = zero
                som(i,:,j,:) = zero
                soil_n_min(i,j,:) = zero
                litter(i,:,j,:,:) = zero
                bm_to_litter(i,j,:,:) = zero
                turnover_daily(i,j,:,:) = zero
                sugar_load(i,j) = un
             ENDIF
 
          ENDIF ! End if PFT's coverage reduction
          
       ENDDO ! Loop over # PFTs

    ENDDO ! Loop over # pixels - domain size
       
    !! 4. history
    convflux        = convflux/one_year*dt_days
    convfluxpft     = convfluxpft/one_year*dt_days
    fDeforestToProduct= fDeforestToProduct/one_year*dt_days
    fLulccResidue   = fLulccResidue/one_year*dt_days
    nflux_prod_total = nflux_prod_total/one_year*dt_days

    IF (printlev>=4) WRITE(numout,*) 'Leaving lcchange_main'
    
  END SUBROUTINE lcchange_main

  
  !! ================================================================================================================================
!! SUBROUTINE   : wood_use_main
!!
!>\BRIEF        Carbon dynamics of the 10 year and 100 year wood use pool 
!!
!! DESCRIPTION  : This subroutine is always activate even if the VEGET_UPDATE=0Y.
!!  Hence, wood decomposition is calculated even if land cover change is not used.
!!  This guarantees that wood decomposition is correctly accounted for in an experiment
!!  where land cover change is first used and then stopped to use. One example could be
!!  that land cover change is used in the transient spin-up and then stopped to be used
!!  in one of the factorial experiments.\n
!!  
!!  Decomposition of the product pool is linear in the sens that each year either 1/10
!!  or 1/100 of the carbon and nitrogen pools is being decomposed. This differes from
!!  the typical decomposition functions which are assumed to be exponential but which
!!  are described a Q10 rather than a longivety.
!!
!!  Wood product pools are filled in lcchange_main when land cover change occurs and the
!!  decomposition of the annual pool (which only occurs when there is a land cover change)
!!  is also calculated in lcchange_main. This routine only updates the 10 year and 100
!!  year wood pools. 
!!
!! Main structure of wood_use_main is:
!! 1. Initialize  
!! 2. Update 10-year and 100-year turnover pool contents
!! 3. Write output files
!!
!! RECENT CHANGE(S) : None
!!
!! MAIN OUTPUT VARIABLE(S) : ::prod10, ::prod100, ::flux10, ::flux100,
!!   :: cflux_prod10 and :: cflux_prod100 
!!
!! REFERENCES   : None
!!
!! FLOWCHART    : 
!! \latexonly 
!!     \includegraphics[scale=0.5]{lcchange.png}
!! \endlatexonly
!! \n
  !_ ================================================================================================================================

  SUBROUTINE wood_use_main (npts, dt_days, cflux_prod10, cflux_prod100, flux10, flux100, &
       prod10, prod100)
  
  !! 0. Variable and parameter declaration 
    
    !! 0.1 Input variables
    INTEGER, INTENT(in)                                       :: npts             !! Domain size - number of pixels (unitless)
    REAL(r_std), INTENT(in)                                   :: dt_days          !! Time step of vegetation dynamics for stomate
                                                                                  !! (days)

    !! 0.2 Output variables
    REAL(r_std), DIMENSION(npts), INTENT(out)                 :: cflux_prod10     !! total annual release from the 10 year-turnover
                                                                                  !! pool @tex ($gC m^{-2}$) @endtex
    REAL(r_std), DIMENSION(npts), INTENT(out)                 :: cflux_prod100    !! total annual release from the 100 year-
                                                                                  !! turnover pool @tex ($gC m^{-2}$) @endtex

    !! 0.3 Modified variables
    REAL(r_std), DIMENSION(npts,0:10), INTENT(inout)          :: prod10           !! products remaining in the 10 year-turnover
                                                                                  !! pool after the annual release for each 
                                                                                  !! compartment (10 + 1 : input from year of land
                                                                                  !! cover change)
    REAL(r_std), DIMENSION(npts,0:100), INTENT(inout)         :: prod100          !! products remaining in the 100 year-turnover
                                                                                  !! pool after the annual release for each 
                                                                                  !! compartment (100 + 1 : input from year of land
                                                                                  !! cover change)
    REAL(r_std), DIMENSION(npts,10), INTENT(inout)            :: flux10           !! annual release from the 10/100 year-turnover 
                                                                                  !! pool compartments
    REAL(r_std), DIMENSION(npts,100), INTENT(inout)           :: flux100          !! annual release from the 10/100 year-turnover
                                                                                  !! pool compartments
 
    !! 0.4 Local variables
    INTEGER(i_std)                                            :: i, l, m          !! indices (unitless)

!_ ================================================================================================================================

    IF (printlev>=3) WRITE(numout,*) 'Entering wood_use_main'

    !! 1. Initialization
    cflux_prod10(:)     = zero
    cflux_prod100(:)    = zero
    
    !! 2. Decompose the wood product pool
    !  The annual flux is accounted for in lcchange_main and only occurs the
    !  year of a land cover change. The 10 year and 100 year pools need to be
    !  updated even if land cover change is no longer accounted for and are
    !  there subject to their own subroutine.
    DO i = 1,npts

       !! Update 10 year-turnover pool content following flux emission
       !! (linear decay (10%) of the initial carbon input)
       DO  l = 0, 8
          m = 10 - l
          cflux_prod10(i) =  cflux_prod10(i) + flux10(i,m)
          prod10(i,m)     =  prod10(i,m-1)   - flux10(i,m-1)
          flux10(i,m)     =  flux10(i,m-1)
        
          !+++CHECK+++
          ! This variable always has the same dimensions and the
          ! code always loops over all dimensions irrespective whether
          ! they have a non-zero value or not. The line below is
          ! NOT conserving mass.
          IF (prod10(i,m) .LT. 1.0) prod10(i,m) = zero
          !+++++++++++
       ENDDO
       
       cflux_prod10(i) = cflux_prod10(i) + flux10(i,1) 
       flux10(i,1)     = 0.1 * prod10(i,0)
       prod10(i,1)     = prod10(i,0)
       
       !! Update 100 year-turnover pool content following flux emission\n
       DO   l = 0, 98
          m = 100 - l
          cflux_prod100(i)  =  cflux_prod100(i) + flux100(i,m)
          prod100(i,m)      =  prod100(i,m-1)   - flux100(i,m-1)
          flux100(i,m)      =  flux100(i,m-1)
          
          !+++CHECK+++
          ! This variable always has the same dimensions and the
          ! code always loops over all dimensions irrespective whether
          ! they have a non-zero value or not. The line below is
          ! NOT conserving mass.
          IF (prod100(i,m).LT.1.0) prod100(i,m) = zero
          !+++++++++++
       ENDDO
       
       cflux_prod100(i)  = cflux_prod100(i) + flux100(i,1) 
       flux100(i,1)      = 0.01 * prod100(i,0)
       prod100(i,1)      = prod100(i,0)
       prod10(i,0)        = zero
       prod100(i,0)       = zero 

       
    ENDDO ! Loop over # pixels - domain size
    
    !! 4. history
    cflux_prod10    = cflux_prod10/one_year*dt_days
    cflux_prod100   = cflux_prod100/one_year*dt_days

    IF (printlev>=4) WRITE(numout,*) 'Leaving wood_use_main'

  END SUBROUTINE wood_use_main

 !! ================================================================================================================================
!! SUBROUTINE   : product_init
!!
!>\BRIEF        Initialize 10 year and 100 year wood use pool in years without lcchange 
!!
!! DESCRIPTION  : This subroutine is only used when VEGET_UPDATE=0Y. In those years
!! prod10 and prod100 are initialized such that the wood_use can be accounted for.
!!
!! RECENT CHANGE(S) : None
!!
!! MAIN OUTPUT VARIABLE(S) : ::prod10, ::prod100
!!
!! REFERENCES   : None
!!
!! FLOWCHART    : 
!! \latexonly 
!!     \includegraphics[scale=0.5]{lcchange.png}
!! \endlatexonly
!! \n
  !_ ================================================================================================================================

  SUBROUTINE product_init (npts, prod10, prod100, flux10, flux100, convflux, &
       nflux_prod_total, convfluxpft, fDeforestToProduct, fLulccResidue)

  
  !! 0. Variable and parameter declaration 
    
    !! 0.1 Input variables
    INTEGER, INTENT(in)                                       :: npts               !! Domain size - number of pixels (unitless)


    !! 0.2 Output variables
    REAL(r_std), DIMENSION(npts), INTENT(out)                 :: convflux           !! release during first year following land cover
                                                                                    !! change
    REAL(r_std), DIMENSION(npts), INTENT(out)                 :: nflux_prod_total   !! release of N associated to land cover change  @tex ($gN m^{-2}$) @endtex  
    REAL(r_std), DIMENSION(npts,nvm), INTENT(out)             :: convfluxpft        !! release during first year following land cover                                       
                                                                                    !! change   
    REAL(r_std), DIMENSION(npts,nvm), INTENT(out)             :: fDeforestToProduct !!  Deforested biomass into product pool due to anthorpogenic 
                                                                                    !! land use change
    REAL(r_std), DIMENSION(npts,nvm), INTENT(out)             :: fLulccResidue      !!  carbon mass flux into soil and litter due to anthropogenic land use or land cover change

    !! 0.3 Modified variables
    REAL(r_std), DIMENSION(npts,0:10), INTENT(inout)          :: prod10             !! products remaining in the 10 year-turnover
                                                                                    !! pool after the annual release for each 
                                                                                    !! compartment (10 + 1 : input from year of land
                                                                                    !! cover change)
    REAL(r_std), DIMENSION(npts,0:100), INTENT(inout)         :: prod100            !! products remaining in the 100 year-turnover
                                                                                    !! pool after the annual release for each 
                                                                                    !! compartment (100 + 1 : input from year of land
                                                                                    !! cover change)
    REAL(r_std), DIMENSION(npts,0:10), INTENT(inout)          :: flux10             !! annual release from the 10/100 year-turnover 
                                                                                    !! pool compartments
    REAL(r_std), DIMENSION(npts,0:100), INTENT(inout)         :: flux100            !! annual release from the 10/100 year-turnover
                                                                                    !! pool compartments

    !! 0.4 Local variables

!_ ================================================================================================================================

    IF (printlev>=3) WRITE(numout,*) 'Entering product_init'

    prod10(:,0)         = zero
    prod100(:,0)        = zero 
    flux10(:,0)         = zero
    flux100(:,0)        = zero
    convflux(:) = zero
    nflux_prod_total(:) = zero
    convfluxpft(:,:) = zero
    fDeforestToProduct(:,:) = zero 
    fLulccResidue(:,:) = zero

    IF (printlev>=4) WRITE(numout,*) 'Leaving product_init'
    
  END SUBROUTINE product_init
  
END MODULE stomate_lcchange
